%% Experiment 1
% %% Uses structure objects

% Compressed Sensing in On-Grid MIMO Radar 
% Test Simulations, SNR = 30dB, random array
% OMP, L1 Square Non Negative Regularization  and
% L1/L2 Constrained Non Negative

% Michael F Minner

%% Clear
clear all;

%% Simulation information

% For each sparsity level, generate N_S signals, N_M matrices
Sparsity_Levels=2:2:28;

N_S=10;N_A=10;N_ss=size(Sparsity_Levels,2);  % Number of signals, random arrays, sparsity levels
N_Sim=N_S*N_A;                             % Number of simulations for each sparsity level

threshold=[.001,.01,.1];                   % Consider different threshold levels for detection
N_thresh=size(threshold,2);                % Number of thresholds considered

SNR=30;            % Signal to noise ratio in dB

OMP.AvgProbD=zeros(N_ss,N_thresh);         % Average of the probabilities of detection
OMP.AvgProbFA=zeros(N_ss,N_thresh);        % and false alarms for each threshold level
OMP.AvgRelErr=zeros(N_ss,N_thresh);        % Average relative error with thresholding
OMP.AvgRelErrNT=zeros(N_ss,1);             % Average relative error without thresholding
OMP.AvgTime=zeros(N_ss,1);                 % Average time to evaluate OMP
OMP.AvgNbrItr=zeros(N_ss,1);               % Average number of iterations for OMP

OMP_ProbD=zeros(N_Sim,N_thresh);           % Probabilities of detection and false alarm
OMP_ProbFA=zeros(N_Sim,N_thresh);          % for each simulation
OMP_RelErr=zeros(N_Sim,N_thresh);          % Relative error for each simulation with thresholding
OMP_RelErrNT=zeros(N_Sim,1);               % Relative error for each simulation without thresholding
OMP_Time=zeros(N_Sim,1);                   % Time to evaluate OMP
OMP_NbrItr=zeros(N_Sim,1);                 % Number of Iterations to evaluate OMP
% each row is a separate simulation,
% each column is a different threshold

% Repeat for AISS, L1SQNN, L1L2CNN (YALL1)

% AISS.AvgProbD=zeros(N_ss,N_thresh);
% AISS.AvgProbFA=zeros(N_ss,N_thresh);
% AISS.AvgRelErr=zeros(N_ss,N_thresh);
% AISS.AvgRelErrNT=zeros(N_ss,1);
% AISS.AvgTime=zeros(N_ss,1);
% AISS.AvgNbrItr=zeros(N_ss,1);
% 
% AISS_ProbD=zeros(N_Sim,N_thresh);
% AISS_ProbFA=zeros(N_Sim,N_thresh);
% AISS_RelErr=zeros(N_Sim,N_thresh);
% AISS_RelErrNT=zeros(N_Sim,1);
% AISS_Time=zeros(N_Sim,1);
% AISS_NbrItr=zeros(N_Sim,1);


L1SQNN.AvgProbD=zeros(N_ss,N_thresh);
L1SQNN.AvgProbFA=zeros(N_ss,N_thresh);
L1SQNN.AvgRelErr=zeros(N_ss,N_thresh);
L1SQNN.AvgRelErrNT=zeros(N_ss,1);
L1SQNN.AvgTime=zeros(N_ss,1);
L1SQNN.AvgNbrItr=zeros(N_ss,1);

L1SQNN_ProbD=zeros(N_Sim,N_thresh);
L1SQNN_ProbFA=zeros(N_Sim,N_thresh);
L1SQNN_RelErr=zeros(N_Sim,N_thresh);
L1SQNN_RelErrNT=zeros(N_Sim,1);
L1SQNN_Time=zeros(N_Sim,1);
L1SQNN_NbrItr=zeros(N_Sim,1);


L1L2CNN.AvgProbD=zeros(N_ss,N_thresh);
L1L2CNN.AvgProbFA=zeros(N_ss,N_thresh);
L1L2CNN.AvgRelErr=zeros(N_ss,N_thresh);
L1L2CNN.AvgRelErrNT=zeros(N_ss,1);
L1L2CNN.AvgTime=zeros(N_ss,1);
L1L2CNN.AvgNbrItr=zeros(N_ss,1);

L1L2CNN_ProbD=zeros(N_Sim,N_thresh);
L1L2CNN_ProbFA=zeros(N_Sim,N_thresh);
L1L2CNN_RelErr=zeros(N_Sim,N_thresh);
L1L2CNN_RelErrNT=zeros(N_Sim,1);
L1L2CNN_Time=zeros(N_Sim,1);
L1L2CNN_NbrItr=zeros(N_Sim,1);

fname=['Experiment_1_Sparisty_Levels_', num2str(N_ss), '.mat'];
%% Initialization


M=5;         % # of Transmitters
N=5;         % # of Receivers.
Q=15;         % # of samples


U=10;         % # of Azimuth Bins
V=10;         % # of Range Bins
W=10;         % # of Doppler Bins

K=U*V*W;      % total # of Bins

P=10;          % sparsity of the target scene

c=3e8;             % speed of light

B=15e6;            % Bandwidth of each transmitted signal 15MHz
T=2e-6;            % Waveform pulse duration
f_c=1e10;          % Carrier frequency of the first transmitter 10GHz
lambda=c/f_c;      % Reference carrier wavelength, lambda = c/f_c
alpha=B/T;         % Chirp rate, alpha=B/T

Range_U=[-.1,.1];                 % range of angles (-.1 to .1) in radians
Range_V=[990,1010];               % range of distances in meters (980 to 1020 meters)
Range_W=[0,30];                   % range of speeds (0 to 30 meters per second)

Range_tau=2.*Range_V./c;          % range of time delays
Range_upsilon=2/lambda.*Range_W;  % range of Doppler shifts

Delta_U=(Range_U(2)-Range_U(1))/U;      % step size in each domain
Delta_V=(Range_V(2)-Range_V(1))/V;
Delta_W=(Range_W(2)-Range_W(1))/W;

Delta_tau=(Range_tau(2)-Range_tau(1))/V;
Delta_upsilon=(Range_upsilon(2)-Range_upsilon(1))/W;

Values_U=Range_U(1):Delta_U:Range_U(2)-Delta_U; % values for each bin
Values_V=Range_V(1):Delta_V:Range_V(2)-Delta_V; % remove additional final bin
Values_W=Range_W(1):Delta_W:Range_W(2)-Delta_W;

Values_tau=Range_tau(1):Delta_tau:Range_tau(2)-Delta_tau;
Values_upsilon=Range_upsilon(1):Delta_upsilon:Range_upsilon(2)-Delta_upsilon;

% Sample in time only for targets in the scene...
T_d=Range_tau(2)-Range_tau(1);  % Sample time duration
Delta_Q=T_d/Q;                  % Sample times
Values_T_d=Range_tau(1):Delta_Q:Range_tau(2)-Delta_Q;



%% Simulations

timeStart=tic;
index1=1; % Index for the total number of simulations performed

index4=1; % Index for sparsity
for ss=Sparsity_Levels   % Vary the sparsity level
    
    index2=1; % Index for number of simulations per sparsity
    
    % Calculations for measurement matrices
    [~, weight,A_F, A_G, A_H] = LinearChirp( M,Q,V,W,alpha,T,f_c,Values_tau, Values_upsilon, Values_T_d );
    
    for ii=1:N_A          % The number of signals to generate
        
        % ULA Locations
        %[ p,q] = AntennaPositionUniform(M,N,lambda);
        % Random Antenna Locations
        [ p,q ] = AntennaPositionRandom(M,N);
        
        % Build Antenna Arrays
        [A_T,A_R] = AntennaArray( p,q,lambda, M,N,U,Values_U);
        
        % Measurement Matrix
        %[ A ] = MeasurementMatrix(A_R, A_T, A_F, A_G, A_H, weight,M,N,Q,U,V,W,K);
        [ A ] = MeasurementMatrixVectorized(A_R, A_T, A_F, A_G, A_H, weight,M,N,Q,U,V,W,K);
        
        
        for kk=1:N_S
            
            %Mag=2;            % Magnitude of target reflectivities
            [signal, grid, supp] = TargetScene(ss,U,V,W,K);
            
            % All ones on the support
            signal(supp)=ones(ss,1);
            
            % Take Measurements
            y=A*signal;
            
            % Complex separation
            x=[real(signal);imag(signal)];
            B=[real(A),-imag(A);imag(A),real(A)];
            z=B*x;
            
            % Generate Noise
            PowerSignal=norm(signal(supp)).^2;
            %PowerSignal=norm(y).^2;
            NoiseStdDev=sqrt(PowerSignal/(2*M*N*Q*power(10,SNR/10)));                 % Standard deviation of the noise
            noise=NoiseStdDev.*randn(M*N*Q,1)+NoiseStdDev*1i.*randn(M*N*Q,1);        % Complex Gaussian noise
            
            %noisey measurments
            y=y+noise;
            z=[real(y);imag(y)];
            
            % Recovery
            
            % OMP
            tStartOMP=tic;
            [xOMP,~,~,NbrItrOMP] = omp(y,A,[],200,norm(noise));
            OMP_Time(index2,1)=toc(tStartOMP);
            OMP_NbrItr(index2,1)=NbrItrOMP;
            OMP_RelErrNT(index2,1)=norm(xOMP-signal)/sqrt(PowerSignal);
            xOMP_Abs=abs(xOMP);
            
            
%             % AISS
%             tStartAISS=tic;
%             % [xAISS,~,NbrItrAISS]=CSinvscalespace(B,z);
%             [xAISS,~,NbrItrAISS]=CSinvscalespaceT(B,z);
%             AISS_Time(index2,1)=toc(tStartAISS);
%             AISS_NbrItr(index2,1)=NbrItrAISS;
%             xAISS=xAISS(1:K)+1i.*xAISS(K+1:end);
%             AISS_RelErrNT(index2,1)=norm(xAISS-signal)/sqrt(PowerSignal);
%             xAISS_Abs=abs(xAISS);
            
            
            % L1SQNN
            tStartL1SQNN=tic;
            [xL1SQNN,~,~,NbrItrL1SQNN] = l1sqnnreg(z,B,30);
            L1SQNN_Time(index2,1)=toc(tStartL1SQNN);
            L1SQNN_NbrItr(index2,1)=NbrItrL1SQNN;
            xL1SQNN=xL1SQNN(1:K)+1i.*xL1SQNN(K+1,end);
            L1SQNN_RelErrNT(index2,1)=norm(xL1SQNN-signal)/sqrt(PowerSignal);
            xL1SQNN_Abs=abs(xL1SQNN);
            
            
            % L1L2CNN
            %
            clear opts;
            opts.tol = 1e-10; opts.noNN=1;opts.delta = norm(noise);
            tStartL1L2CNN=tic;
            [xL1L2CNN,Out] = yall1(B,z, opts);
            L1L2CNN_Time(index2,1)=toc(tStartL1L2CNN);
            L1L2CNN_NbrItr(index2,1)=Out.iter;
            xL1L2CNN=xL1L2CNN(1:K)+1i.*xL1L2CNN(K+1:end);
            L1L2CNN_RelErrNT(index2,1)=norm(xL1L2CNN-signal)/sqrt(PowerSignal);
            xL1L2CNN_Abs=abs(xL1L2CNN);
            
            index3=1;
            
            for t=threshold
                
                Removed_OMP=find(xOMP_Abs<t);  % Set entries less than current threshold to zero.
                xOMP(Removed_OMP)=0;
                xOMP_Abs(Removed_OMP)=0;
                SuppOMP=find(xOMP_Abs>=t);     % Support after thresholding
                OMP_RelErr(index2,index3)=norm(xOMP-signal)/sqrt(PowerSignal);              % Relative error after thresholding
                OMP_ProbD(index2,index3)=sum(xOMP_Abs(supp,1)>=t)/ss;                       % Fraction of true targets detected
                OMP_ProbFA(index2,index3)=sum(xOMP_Abs(setdiff(SuppOMP,supp),1)>=t)/(K-ss); % Fraction of false alarms
                
%                 Removed_AISS=find(xAISS_Abs<t);
%                 xAISS(Removed_AISS)=0;
%                 xAISS_Abs(Removed_AISS)=0;
%                 SuppAISS=find(xAISS_Abs>=t);
%                 AISS_RelErr(index2,index3)=norm(xAISS-signal)/sqrt(PowerSignal);
%                 AISS_ProbD(index2,index3)=sum(xAISS_Abs(supp,1)>=t)/ss;
%                 AISS_ProbFA(index2,index3)=sum(xAISS_Abs(setdiff(SuppAISS,supp),1)>=t)/(K-ss);
                
                Removed_L1SQNN=find(xL1SQNN_Abs<t);
                xL1SQNN(Removed_L1SQNN)=0;
                xL1SQNN_Abs(Removed_L1SQNN)=0;
                SuppL1SQNN=find(xL1SQNN_Abs>=t);
                L1SQNN_RelErr(index2,index3)=norm(xL1SQNN-signal)/sqrt(PowerSignal);
                L1SQNN_ProbD(index2,index3)=sum(xL1SQNN_Abs(supp,1)>=t)/ss;
                L1SQNN_ProbFA(index2,index3)=sum(xL1SQNN_Abs(setdiff(SuppL1SQNN,supp),1)>=t)/(K-ss);
                
                Removed_L1L2CNN=find(xL1L2CNN_Abs<t);
                xL1L2CNN(Removed_L1L2CNN)=0;
                xL1L2CNN_Abs(Removed_L1L2CNN)=0;
                SuppL1L2CNN=find(xL1L2CNN_Abs>=t);
                L1L2CNN_RelErr(index2,index3)=norm(xL1L2CNN-signal)/sqrt(PowerSignal);
                L1L2CNN_ProbD(index2,index3)=sum(xL1L2CNN_Abs(supp,1)>=t)/ss;
                L1L2CNN_ProbFA(index2,index3)=sum(xL1L2CNN_Abs(setdiff(SuppL1L2CNN,supp),1)>=t)/(K-ss);
                
                index3=index3+1;
                
            end
            display(['current sparsity: ' num2str(ss) ' current simulation: ' num2str(index2)])
            index2=index2+1;
            index1=index1+1;
        end
    end
    
    OMP.AvgProbD(index4,:)=mean(OMP_ProbD,1);
    OMP.AvgProbFA(index4,:)=mean(OMP_ProbFA,1);
    OMP.AvgRelErr(index4,:)=mean(OMP_RelErr,1);
    OMP.AvgRelErrNT(index4,1)=mean(OMP_RelErrNT,1);
    OMP.AvgTime(index4,1)=mean(OMP_Time,1);
    OMP.AvgNbrItr(index4,1)=mean(OMP_NbrItr,1);
    
%     AISS.AvgProbD(index4,:)=mean(AISS_ProbD,1);
%     AISS.AvgProbFA(index4,:)=mean(AISS_ProbFA,1);
%     AISS.AvgRelErr(index4,:)=mean(AISS_RelErr,1);
%     AISS.AvgRelErrNT(index4,1)=mean(AISS_RelErrNT,1);
%     AISS.AvgTime(index4,1)=mean(AISS_Time,1);
%     AISS.AvgNbrItr(index4,1)=mean(AISS_NbrItr,1);
    
    L1SQNN.AvgProbD(index4,:)=mean(L1SQNN_ProbD,1);
    L1SQNN.AvgProbFA(index4,:)=mean(L1SQNN_ProbFA,1);
    L1SQNN.AvgRelErr(index4,:)=mean(L1SQNN_RelErr,1);
    L1SQNN.AvgRelErrNT(index4,1)=mean(L1SQNN_RelErrNT,1);
    L1SQNN.AvgTime(index4,1)=mean(L1SQNN_Time,1);
    L1SQNN.AvgNbrItr(index4,1)=mean(L1SQNN_NbrItr,1);
    
    L1L2CNN.AvgProbD(index4,:)=mean(L1L2CNN_ProbD,1);
    L1L2CNN.AvgProbFA(index4,:)=mean(L1L2CNN_ProbFA,1);
    L1L2CNN.AvgRelErr(index4,:)=mean(L1L2CNN_RelErr,1);
    L1L2CNN.AvgRelErrNT(index4,1)=mean(L1L2CNN_RelErrNT,1);
    L1L2CNN.AvgTime(index4,1)=mean(L1L2CNN_Time,1);
    L1L2CNN.AvgNbrItr(index4,1)=mean(L1L2CNN_NbrItr,1);
    
    index4=index4+1;
    
    %save(fname, 'OMP', 'AISS', 'L1SQNN', 'L1L2CNN', 'Sparsity_Levels', 'index1', 'index4', 'M', 'N', 'Q', 'U', 'V', 'W', 'K', 'SNR', 'Range_U', 'Range_V', 'Range_W');
    save(fname, 'OMP', 'L1SQNN', 'L1L2CNN', 'Sparsity_Levels', 'index1', 'index4', 'M', 'N', 'Q', 'U', 'V', 'W', 'K', 'SNR', 'Range_U', 'Range_V', 'Range_W');
end
timeStop=toc(timeStart)

%%
figure(1)

subplot(3,2,1)
plot(Sparsity_Levels, OMP.AvgProbD(:,1),'k',Sparsity_Levels,OMP.AvgProbD(:,2),'b',Sparsity_Levels, OMP.AvgProbD(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Prob of True Detection','Fontsize',12)
title('\it{Average Probability of True Detection OMP}','Fontsize',12)

subplot(3,2,2)
plot(Sparsity_Levels,OMP.AvgProbFA(:,1),'k',Sparsity_Levels, OMP.AvgProbFA(:,2),'b',Sparsity_Levels, OMP.AvgProbFA(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Prob of False Alarm','Fontsize',12)
title('\it{Average Probability of False Alarm OMP}','Fontsize',12)

subplot(3,2,3)
plot(Sparsity_Levels,OMP.AvgRelErr(:,1),'k',Sparsity_Levels, OMP.AvgRelErr(:,2),'b',Sparsity_Levels, OMP.AvgRelErr(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error with Thresholding}','Fontsize',12)

subplot(3,2,4)
plot(Sparsity_Levels,OMP.AvgRelErrNT,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error without Thresholding}','Fontsize',12)

subplot(3,2,5)
plot(Sparsity_Levels,OMP.AvgNbrItr,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Number of Iterations','Fontsize',12)
title('\it{Average Number of Iterations per Sparsity Level}','Fontsize',12)

subplot(3,2,6)
plot(Sparsity_Levels,OMP.AvgTime,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Average Recovery Time (seconds)','Fontsize',12)
title('\it{Average Recovery Time}','Fontsize',12)

% figure(2)
% 
% subplot(3,2,1)
% plot(Sparsity_Levels, AISS.AvgProbD(:,1),'k',Sparsity_Levels,AISS.AvgProbD(:,2),'b',Sparsity_Levels, AISS.AvgProbD(:,3),'r')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Prob of True Detection','Fontsize',12)
% title('\it{Average Probability of True Detection AISS}','Fontsize',12)
% 
% subplot(3,2,2)
% plot(Sparsity_Levels,AISS.AvgProbFA(:,1),'k',Sparsity_Levels, AISS.AvgProbFA(:,2),'b',Sparsity_Levels, AISS.AvgProbFA(:,3),'r')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Avg Prob of False Alarm','Fontsize',12)
% title('\it{Average Probability of False Alarm AISS}','Fontsize',12)
% 
% subplot(3,2,3)
% plot(Sparsity_Levels,AISS.AvgRelErr(:,1),'k',Sparsity_Levels, AISS.AvgRelErr(:,2),'b',Sparsity_Levels, AISS.AvgRelErr(:,3),'r')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Avg Relative Error','Fontsize',12)
% title('\it{Average Relative Error with Thresholding}','Fontsize',12)
% 
% subplot(3,2,4)
% plot(Sparsity_Levels,AISS.AvgRelErrNT,'k')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Avg Relative Error','Fontsize',12)
% title('\it{Average Relative Error without Thresholding}','Fontsize',12)
% 
% subplot(3,2,5)
% plot(Sparsity_Levels,AISS.AvgNbrItr,'k')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Avg Number of Iterations','Fontsize',12)
% title('\it{Average Number of Iterations per Sparsity Level}','Fontsize',12)
% 
% subplot(3,2,6)
% plot(Sparsity_Levels,AISS.AvgTime,'k')
% %axis([0 Sparsity_Levels(end)]);
% xlabel('Sparsity Level','Fontsize',12)
% ylabel('Average Recovery Time (seconds)','Fontsize',12)
% title('\it{Average Recovery Time}','Fontsize',12)


figure(3)
subplot(3,2,1)
plot(Sparsity_Levels, L1SQNN.AvgProbD(:,1),'k',Sparsity_Levels,L1SQNN.AvgProbD(:,2),'b',Sparsity_Levels, L1SQNN.AvgProbD(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Prob of True Detection','Fontsize',12)
title('\it{Average Probability of True Detection L1SQNN}','Fontsize',12)

subplot(3,2,2)
plot(Sparsity_Levels,L1SQNN.AvgProbFA(:,1),'k',Sparsity_Levels, L1SQNN.AvgProbFA(:,2),'b',Sparsity_Levels, L1SQNN.AvgProbFA(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Prob of False Alarm','Fontsize',12)
title('\it{Average Probability of False Alarm L1SQNN}','Fontsize',12)

subplot(3,2,3)
plot(Sparsity_Levels,L1SQNN.AvgRelErr(:,1),'k',Sparsity_Levels, L1SQNN.AvgRelErr(:,2),'b',Sparsity_Levels, L1SQNN.AvgRelErr(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error with Thresholding}','Fontsize',12)

subplot(3,2,4)
plot(Sparsity_Levels,L1SQNN.AvgRelErrNT,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error without Thresholding}','Fontsize',12)

subplot(3,2,5)
plot(Sparsity_Levels,L1SQNN.AvgNbrItr,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Number of Iterations','Fontsize',12)
title('\it{Average Number of Iterations per Sparsity Level}','Fontsize',12)

subplot(3,2,6)
plot(Sparsity_Levels,L1SQNN.AvgTime,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Average Recovery Time (seconds)','Fontsize',12)
title('\it{Average Recovery Time}','Fontsize',12)

figure(4)
subplot(3,2,1)
plot(Sparsity_Levels, L1L2CNN.AvgProbD(:,1),'k',Sparsity_Levels,L1L2CNN.AvgProbD(:,2),'b',Sparsity_Levels, L1L2CNN.AvgProbD(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Prob of True Detection','Fontsize',12)
title('\it{Average Probability of True Detection L1L2CNN}','Fontsize',12)

subplot(3,2,2)
plot(Sparsity_Levels,L1L2CNN.AvgProbFA(:,1),'k',Sparsity_Levels, L1L2CNN.AvgProbFA(:,2),'b',Sparsity_Levels, L1L2CNN.AvgProbFA(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Prob of False Alarm','Fontsize',12)
title('\it{Average Probability of False Alarm L1L2CNN}','Fontsize',12)

subplot(3,2,3)
plot(Sparsity_Levels,L1L2CNN.AvgRelErr(:,1),'k',Sparsity_Levels, L1L2CNN.AvgRelErr(:,2),'b',Sparsity_Levels, L1L2CNN.AvgRelErr(:,3),'r')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error with Thresholding}','Fontsize',12)

subplot(3,2,4)
plot(Sparsity_Levels,L1L2CNN.AvgRelErrNT,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error without Thresholding}','Fontsize',12)

subplot(3,2,5)
plot(Sparsity_Levels,L1L2CNN.AvgNbrItr,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Number of Iterations','Fontsize',12)
title('\it{Average Number of Iterations per Sparsity Level}','Fontsize',12)

subplot(3,2,6)
plot(Sparsity_Levels,L1L2CNN.AvgTime,'k')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Average Recovery Time (seconds)','Fontsize',12)
title('\it{Average Recovery Time}','Fontsize',12)


figure(5)
subplot(3,2,1)
plot(Sparsity_Levels, OMP.AvgProbD(:,1),'k',Sparsity_Levels, Sparsity_Levels, L1SQNN.AvgProbD(:,1),'r',Sparsity_Levels, L1L2CNN.AvgProbD(:,1),'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Prob of True Detection','Fontsize',12)
title('\it{Average Probability of True Detection L1SQNN}','Fontsize',12)

subplot(3,2,2)
plot(Sparsity_Levels,OMP.AvgProbFA(:,1),'k',Sparsity_Levels, Sparsity_Levels, L1SQNN.AvgProbFA(:,1),'r',Sparsity_Levels, L1L2CNN.AvgProbFA(:,1),'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Prob of False Alarm','Fontsize',12)
title('\it{Average Probability of False Alarm L1SQNN}','Fontsize',12)

subplot(3,2,3)
plot(Sparsity_Levels,OMP.AvgRelErr(:,1),'k',Sparsity_Levels, Sparsity_Levels, L1SQNN.AvgRelErr(:,1),'r',Sparsity_Levels, L1L2CNN.AvgRelErr(:,1),'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error with Thresholding}','Fontsize',12)

subplot(3,2,4)
plot(Sparsity_Levels,OMP.AvgRelErrNT,'k', Sparsity_Levels, Sparsity_Levels, L1SQNN.AvgRelErrNT,'r',Sparsity_Levels, L1L2CNN.AvgRelErrNT,'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Relative Error','Fontsize',12)
title('\it{Average Relative Error without Thresholding}','Fontsize',12)

subplot(3,2,5)
plot(Sparsity_Levels,OMP.AvgNbrItr,'k',Sparsity_Levels,Sparsity_Levels, L1SQNN.AvgNbrItr,'r',Sparsity_Levels, L1L2CNN.AvgNbrItr,'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Avg Number of Iterations','Fontsize',12)
title('\it{Average Number of Iterations per Sparsity Level}','Fontsize',12)

subplot(3,2,6)
plot(Sparsity_Levels,OMP.AvgTime,'k',Sparsity_Levels,Sparsity_Levels, L1SQNN.AvgTime,'r',Sparsity_Levels, L1L2CNN.AvgTime,'g')
%axis([0 Sparsity_Levels(end)]);
xlabel('Sparsity Level','Fontsize',12)
ylabel('Average Recovery Time (seconds)','Fontsize',12)
title('\it{Average Recovery Time}','Fontsize',12)