%OMP Orthogonal Matching Pursuit
% OMP(y,A) runs the Orthogonal Matching Pursuit started with x0=0
% Usage: [x,S,NormRes,NbIter] = omp(y,A,S0,MaxNbIter,TolRes)
% y: column vector, A: matrix, S0: initial index set (optional,
% default=[]), MaxNbIter: number of iterations not to be exceeded (optional, default=number of rows of A), TolRes:
% threshold value for the L2-norm of the residual under which the alsogithm
% is stopped (optional, default=1e-4)
% x: column vector, S: support of x, NormRes: the norm of the residual,
% NbIter: the number of performed iterations
% Simon Foucart (created 25/05/2012, modified 25/05/2012)
% NOTE: the matrix A is column-normalized before OMP is run
function [x,S,NormRes,NbIter] = omp(y,A,S0,MaxNbIter,TolRes)

[m,N]=size(A);
if nargin < 5
   TolRes=1e-4; 
end
if nargin < 4
   MaxNbIter=m;
end
if nargin < 3
   S0=[]; 
end

[A,d]=nzedcol(A);
S=S0;
AS=A(:,S);
xS=AS\y;
res=y-AS*xS;
NormRes=norm(res);
NbIter=0;


while ( NbIter < MaxNbIter && NormRes > TolRes )
    [~,j]=max(abs(A'*res));
    S=sort([S, j]);
    AS=A(:,S);
    xS=AS\y;
    res=y-AS*xS;
    NormRes=norm(res);
    NbIter=NbIter+1;
end

x=zeros(N,1); x(S)=diag(1./d(S))*xS;

end
