%% README FILE for "Compressed Sensing in On-Grid MIMO Radar"
% by Michael F Minner.
%
% This folder contains the files needed to reproduce the results
% contained within the paper. These include:
%    The exact code used in each experiment.
%    The resulting data sets from each experiment.
%    MATLAB code to generate the plots for each of these data sets.

% DATA AND PLOTS
%
% These folders contain the data resulting from each experiment 
% (file type '.mat') along with code ('...Plots.m')  to generate 
% the figures contained within the paper (file type '.fig')and 
% additional plots for further analysis.
%
% In order to utilize the '...Plots.m' files, first load the appropriate
% data set then run the desired file.
%
% Note: 'Experiment_4_Plots.m' will automatically load the data due to the
% complexity of the plots.
%
%

% EXPERIMENTS FOLDER
%
% This folder contains all code needed to run the 5 separate experiments.
%
% NOTE: These experiments were run on a server and can take as little as a few 
% hours to 30+ hours to complete depending on hardware specifications
% and problem size.
%
% Please see the paper for references for the associated algorithms used,
% namely for L1 Square Non Negative Regularization,
% L1/L2 Constrained Non Negative from YALL1 and 
% the Adaptive Inverse Scale Space Method.
%
% Experiment_1.m
% Compare different algorithms at different sparsity levels 
% with a fixed SNR and a fixed threshold value.
%
% NOTE: Because the Adaptive Inverse Scale Space Method is not
% publicly available, it has been removed from the folder.
% The original code to use it has been left in but is commented out.
% The results, however, are still available in the folder labeled
% "Experiment 1 Data and Results."
%
% Experiment_2.m
% Compare Random array and Uniform Linear Array (ULA).
% 
% Experiment_3.m
% Compare ROC Curves for L1SQNN as the sparsity varies.
% Compare ROC Curves for L1SQNN as the SNR varies.
%
% Experiment_4.m
% Generate families of ROC Curves for L1SQNN as parameter lambda varies
% at different values of SNR and separate sparsity levels.
%
% Experiment_5.m
% Compare ROC Curves for L1SQNN as when the problem size is increased.
%
% NOTE: Experiment 5 uses a modified built-in MATLAB function (noneglsq)
% purely to save time as it can, at times, seem to run indefinitely.
%
% Experiment_6.m
% Compare ROC Curves for L1SQNN as the bandwidth changes value.
%
%

